<?php
$TRANSLATIONS = array(
"Contacts" => "Контакты",
"Save" => "Сохранить",
"Cancel" => "Отмена",
"OK" => "OK",
"Error" => "Ошибка",
"Download" => "Загрузка",
"Edit" => "Редактировать",
"Delete" => "Удалить",
"Text" => "Текст",
"Family" => "Семья",
"Select groups" => "Выбрать группы",
"Share" => "Сделать общим"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
